# wanha - your pesky URL-guardian for IRC
# Copyright (C) 2007 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package Wanha::Wanha;

use strict;
use warnings FATAL => 'all';
use diagnostics;

use Wanha::DB;


=item add
Add URL

0: original paster nick id
1: wanha paster nick id
2: chan id
3: url id
=cut
sub add($$$$) {
	my ($orig_id, $wanha_id, $chan_id, $url_id) = @_;
	my $update;

	$update = &Wanha::DB::prepare(
			"INSERT INTO wanha (orig, repaste, chan, url) " .
			"VALUES (&da&, &db&, &dc&, &dd&)");
	$update = &Wanha::DB::set($update,
			"a", $orig_id,
			"b", $wanha_id,
			"c", $chan_id,
			"d", $url_id);
	&Wanha::DB::update($update);
}


=item get_info_by_url
Get URL info

0: url
1: chan
r: (id, count, time, nick, ignore, reply)
=cut
sub get_info_by_url($$) {
	my ($url, $chan) = @_;
	my ($query, $result);

	$query = &Wanha::DB::prepare("SELECT id, count, " .
			&Wanha::DB::get_date_fmt("time") . ", " .
			"nick, ignore, reply " .
			"FROM urls " .
			"WHERE url = &sa& AND chan = &db&");
	$query = &Wanha::DB::set($query,
			"a", $url,
			"b", $chan);
	$result = &Wanha::DB::query($query);
	(&Wanha::DB::row_count($result) == 0) && return undef;

	my ($id, $count, $time, $nick, $ignore, $reply) =
		&Wanha::DB::get_row($result);
	$ignore = &Wanha::DB::bool_to_int($ignore);
	return ($id, $count, $time, $nick, $ignore, $reply);
}


=item get_info_by_id
Get URL info

0: URL ID
r: (count, time, nick, url)
=cut
sub get_info_by_id($) {
	my ($url_id) = @_;
	my ($query, $result);

	$query = &Wanha::DB::prepare("SELECT count, " .
			&Wanha::DB::get_date_fmt("time") . ", nick, url " .
			"FROM urls WHERE id = &da&");
	$query = &Wanha::DB::set($query, "a", $url_id);
	$result = &Wanha::DB::query($query);
	(&Wanha::DB::row_count($result) == 0) && return undef;

	my ($count, $time, $nick, $url) = &Wanha::DB::get_row($result);
	return ($count, $time, $nick, $url);
}


=item set_count
Set URL hit count

0: url id
1: count
=cut
sub set_count($$) {
	my ($url_id, $count) = @_;
	my $update;

	$update = &Wanha::DB::prepare("UPDATE urls SET count = &da& " .
			"WHERE id = &db&");
	$update = &Wanha::DB::set($update,
			"a", $count,
			"b", $url_id);
	&Wanha::DB::update($update);
}



return 1;
